/*
 * INodeDiscovery.cs
 *
 * Bread Crumb Trail Control
 * Version: 2.0
 *
 * Copyright (c) 2004, 2006, TopCoder, Inc. All rights reserved
 *
 * Authors: elefth, Standlove
 *          Pops, TCSDEVELOPER
 */

using System;
using System.Web.UI;

namespace TopCoder.Web.UI.WebControl.BreadCrumb
{
    /// <summary>
    /// Defines the contract for classes used to discover the current node.
    /// </summary>
    ///
    /// <remarks>
    /// <para>
    /// The implementation should discover, in it's own way, the current node when
    /// <see cref="GetCurrentNode"/> is called and return the node representation of that url.
    /// </para>
    /// <para>
    /// Implementations of this class will be created in the <see cref="BreadCrumbTrailControl.RenderContents"/>
    /// method of the <see cref="BreadCrumbTrailControl"/> via the object factory and
    /// will be called to determine the current node. The node representation of the current url
    /// (plus sorted query strings) will then be returned by the implementing class and
    /// used to discover the path to the root (ie a <see cref="IPathDiscovery"/> call).
    /// </para>
    /// <para>
    /// <b>Thread Safety:</b> Implementations should be thread safe in the context of the rendering process.
    /// </para>
    /// </remarks>
    public interface INodeDiscovery
    {
        /// <summary>
        /// Called to retrieve the node representation of the current page/title.
        /// </summary>
        ///
        /// <remarks>
        /// If the current page could not be found or is not applicable - simply return null.
        /// The returned node should include any query strings (sorted in ascending order) available
        /// in the <see cref="BreadCrumbNode.Url"/> attribute of the node. Please note that
        /// the title passed can be null if the title should be picked up from the site map instead.
        /// </remarks>
        ///
        /// <param name="title">
        /// A possibly null or empty trimmed title to use.
        /// </param>
        /// <param name="page">
        /// A non-null page to retrieve the node for.
        /// </param>
        ///
        /// <returns>
        /// A <see cref="BreadCrumbNode"/> representation of the current url.
        /// </returns>
        ///
        /// <exception cref="ArgumentNullException">
        /// <paramref name="page"/> is a null reference.
        /// </exception>
        /// <exception cref="BreadCrumbException">
        /// Any error occurs discovering the page.
        /// </exception>
        BreadCrumbNode GetCurrentNode(string title, Page page);
    }
}
