/*
 * TestBreadCrumbTrailControlRender.cs
 *
 * Bread Crumb Trail Control
 * Version: 2.0
 *
 * Copyright (c) 2004, 2006, TopCoder, Inc. All rights reserved
 *
 * Authors: Standlove, TCSDEVELOPER
 */

using System;
using System.Collections;
using NUnit.Framework;
using NUnit.Extensions.Asp;
using NUnit.Extensions.Asp.AspTester;

namespace TopCoder.Web.UI.WebControl.BreadCrumb.Tests
{
    /// <summary>
    /// Tests that RenderContents render correctly by visiting
    /// the demo folder and asserting that correct html is written.
    /// </summary>
    [TestFixture]
    public class TestBreadCrumbTrailControlRender : WebFormTestCase
    {
        /// <summary>
        /// The path of the aspx demo files.
        /// </summary>
        private const string DemoPath = TestCommon.AppPath + "/Demo";

        /// <summary>
        /// The url of the aspx used to demo.
        /// </summary>
        private const string TestUrl = TestCommon.IisServer + DemoPath;

        /// <summary>
        /// Represents the bcc control. Initialized in SetUp.
        /// </summary>
        private LabelTester bcc;

        /// <summary>
        /// The bcc tag for the main page.
        /// {0} is the place holder for first page title.
        /// This could be Main Page or Main Node depending whether we have visited it first.
        /// </summary>
        private const string MainBcc = "<a class=\"ConfigRNS\" onmouseover=\"this.className='ConfigMOS'\" "
            + "onmouseout=\"this.className='ConfigRNS'\" href=\"/BreadCrumbTrailWeb/Demo/Main.aspx\">"
            + "{0}</a>";

        /// <summary>
        /// Initializes the control testers.
        /// </summary>
        protected override void SetUp()
        {
            bcc = new LabelTester("bcc", CurrentWebForm);
        }

        /// <summary>
        /// Tests going to Main page. One node is rendered.
        /// </summary>
        [Test]
        public void TestMain()
        {
            // go to Main page
            Browser.GetPage(TestUrl + "/Main.aspx");
            AssertEquals("Main bcc not rendered incorrectly",
                string.Format(MainBcc, "Main Page"), bcc.Text);
        }

        /// <summary>
        /// Tests going to Forums page. Two nodes are rendered.
        /// </summary>
        [Test]
        public void TestForums()
        {
            // goto Forum page without going Main page (notice title is different)
            Browser.GetPage(TestUrl + "/Forums/Forums.aspx");
            string forumsBcc = string.Format(MainBcc, "Main node") +
                "<span class=\"ConfigPSS\"> &gt; </span>"
                + "<a class=\"ConfigCNS\" onmouseover=\"this.className='ConfigMOS'\" "
                + "onmouseout=\"this.className='ConfigCNS'\" href=\"/BreadCrumbTrailWeb/Demo/Forums/Forums.aspx\">"
                + "Forums Page</a>";
            AssertEquals("Forums bcc rendered incorrectly", forumsBcc, bcc.Text);
        }

        /// <summary>
        /// Tests going to Help page. Three nodes are rendered.
        /// </summary>
        [Test]
        public void TestHelp()
        {
            // goto Help page without visiting the previous 2 nodes
            Browser.GetPage(TestUrl + "/Forums/Help.aspx");
            string helpBcc = string.Format(MainBcc, "Main node") +
                "<span class=\"ConfigPSS\"> &gt; </span>"
                + "<a class=\"ConfigNS\" onmouseover=\"this.className='ConfigMOS'\" "
                + "onmouseout=\"this.className='ConfigNS'\" href=\"/BreadCrumbTrailWeb/Demo/Forums/Forums.aspx\">"
                + "Forums node</a>"

                + "<span class=\"ConfigPSS\"> &gt; </span>"
                + "<a class=\"ConfigCNS\" onmouseover=\"this.className='ConfigMOS'\" "
                + "onmouseout=\"this.className='ConfigCNS'\" href=\"/BreadCrumbTrailWeb/Demo/Forums/Help.aspx\">"
                + "Help Page</a>";
            AssertEquals("Help bcc rendered incorrectly", helpBcc, bcc.Text);
        }
    }
}
